Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(360)

Unified Diff: webrtc/modules/audio_coding/codecs/isac/fix/test/test_iSACfixfloat.c

Issue 1179953003: Revert "Upconvert various types to int." (Closed) Base URL: https://chromium.googlesource.com/external/webrtc@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/audio_coding/codecs/isac/fix/test/test_iSACfixfloat.c
diff --git a/webrtc/modules/audio_coding/codecs/isac/fix/test/test_iSACfixfloat.c b/webrtc/modules/audio_coding/codecs/isac/fix/test/test_iSACfixfloat.c
index 96688b9fc23c380ad6a45e96926971fa65c9bb82..b4c0ee45b9f0e302eb423082034f6235d51a33ab 100644
--- a/webrtc/modules/audio_coding/codecs/isac/fix/test/test_iSACfixfloat.c
+++ b/webrtc/modules/audio_coding/codecs/isac/fix/test/test_iSACfixfloat.c
@@ -88,8 +88,8 @@ int main(int argc, char* argv[]) {
int16_t CodingMode;
int16_t bottleneck;
- int framesize = 30; /* ms */
- // int framesize = 60; /* To invoke cisco complexity case at frame 2252 */
+ int16_t framesize = 30; /* ms */
+ // int16_t framesize = 60; /* To invoke cisco complexity case at frame 2252 */
int cur_framesmpls, err;
@@ -99,7 +99,7 @@ int main(int argc, char* argv[]) {
double length_file;
int16_t stream_len = 0;
- int declen;
+ int16_t declen;
int16_t shortdata[FRAMESAMPLES_10ms];
int16_t decoded[MAX_FRAMESAMPLES];

Powered by Google App Engine
This is Rietveld 408576698